from django import template
from django.db.models import get_model

register = template.Library()

@register.tag(name="section")
def do_section(parser, token):
	try:
		tag_name, identifier = token.split_contents()
	except ValueError:
		raise template.TemplateSyntaxError, "%r tag requires a single argument" % token.contents.split()[0]
	nodelist = parser.parse(('endsection',))
	parser.delete_first_token()
	return SectionNode(nodelist, identifier)

@register.tag(name="entity")
def do_entity(parser, token):
	try:
		tag_name, type, identifier = token.split_contents()
	except ValueError:
		raise template.TemplateSyntaxError, "%r tag requires two arguments" % token.contents.split()[0]
	return EntityNode(type, identifier)

class SectionNode(template.Node):

	def __init__(self, nodelist, identifier):
		try:
			section = get_model("blockedit", "section").objects.get(identifier=identifier)
		except:
			section = get_model("blockedit", "section")(identifier=identifier)
			section.title = section.identifier.replace("_", " ").capitalize()
			section.save()
		self.section = section
		self.nodelist = nodelist

	def render(self, context):
		context["section"] = self.section
		return self.nodelist.render(context)

class EntityNode(template.Node):
	def __init__(self, type, identifier):
		self.type = type
		self.identifier = identifier
		self.types = {
			"text": "textentity",
			"longtext": "longtextentity"
		}
	def render(self, context):
		try:
			entity = get_model("blockedit", self.types.get(self.type)).objects.filter(section=context["section"]).get(identifier=self.identifier)
		except:
			entity = get_model("blockedit", self.types.get(self.type))(identifier=self.identifier, section=context["section"])
			entity.title = entity.identifier.replace("_", " ").capitalize()
			entity.content = "".join(["[", entity.title, "]"])
			entity.save()
		return entity.content;
	